@@ -37,14 +37,10 @@ def create_toolbar_tokens_func(pgcli):
             if pgcli.multiline_mode == "safe":
                 result.append(("class:bottom-toolbar", " ([Esc] [Enter] to execute]) "))
             else:
-                result.append(
-                    ("class:bottom-toolbar", " (Semi-colon [;] will end the line) ")
-                )
+                result.append(("class:bottom-toolbar", " (Semi-colon [;] will end the line) "))
 
         if pgcli.vi_mode:
-            result.append(
-                ("class:bottom-toolbar", "[F4] Vi-mode (" + _get_vi_mode() + ")  ")
-            )
+            result.append(("class:bottom-toolbar", "[F4] Vi-mode (" + _get_vi_mode() + ")  "))
         else:
             result.append(("class:bottom-toolbar", "[F4] Emacs-mode  "))
 
@@ -54,14 +50,10 @@ def create_toolbar_tokens_func(pgcli):
             result.append(("class:bottom-toolbar", "[F5] Explain: OFF "))
 
         if pgcli.pgexecute.failed_transaction():
-            result.append(
-                ("class:bottom-toolbar.transaction.failed", "     Failed transaction")
-            )
+            result.append(("class:bottom-toolbar.transaction.failed", "     Failed transaction"))
 
         if pgcli.pgexecute.valid_transaction():
-            result.append(
-                ("class:bottom-toolbar.transaction.valid", "     Transaction")
-            )
+            result.append(("class:bottom-toolbar.transaction.valid", "     Transaction"))
 
         if pgcli.completion_refresher.is_refreshing():
             result.append(("class:bottom-toolbar", "     Refreshing completions..."))
