@@ -39,9 +39,7 @@ def test_generate_alias_uses_upper_case_letters_from_name(table_name, alias):
         ("sometable", "s"),
     ],
 )
-def test_generate_alias_uses_first_char_and_every_preceded_by_underscore(
-    table_name, alias
-):
+def test_generate_alias_uses_first_char_and_every_preceded_by_underscore(table_name, alias):
     assert pgcompleter.generate_alias(table_name) == alias
 
 
@@ -49,9 +47,7 @@ def test_generate_alias_uses_first_char_and_every_preceded_by_underscore(
     "table_name, alias_map, alias",
     [
         ("some_table", {"some_table": "my_alias"}, "my_alias"),
-        pytest.param(
-            "some_other_table", {"some_table": "my_alias"}, "sot", id="no_match_in_map"
-        ),
+        pytest.param("some_other_table", {"some_table": "my_alias"}, "sot", id="no_match_in_map"),
     ],
 )
 def test_generate_alias_can_use_alias_map(table_name, alias_map, alias):
@@ -83,9 +79,7 @@ def test_pgcompleter_alias_uses_configured_alias_map(table_name, alias_map, alia
         ("SomeTable", {"SomeTable": "my_alias"}, "my_alias"),
     ],
 )
-def test_generate_alias_prefers_alias_over_upper_case_name(
-    table_name, alias_map, alias
-):
+def test_generate_alias_prefers_alias_over_upper_case_name(table_name, alias_map, alias):
     assert pgcompleter.generate_alias(table_name, alias_map) == alias
 
 
