@@ -90,8 +90,8 @@ def test_expanded_slash_G(executor, pgspecial):
     # Tests whether we reset the expanded output after a \G.
     run(executor, """create table test(a boolean)""")
     run(executor, """insert into test values(True)""")
-    results = run(executor, r"""select * from test \G""", pgspecial=pgspecial)
-    assert pgspecial.expanded_output == False
+    run(executor, r"""select * from test \G""", pgspecial=pgspecial)
+    assert pgspecial.expanded_output is False
 
 
 @dbtest
@@ -132,9 +132,7 @@ def test_schemata_table_views_and_columns_query(executor):
     # views
     assert set(executor.views()) >= {("public", "d")}
 
-    assert set(executor.view_columns()) >= {
-        ("public", "d", "e", "integer", False, None)
-    }
+    assert set(executor.view_columns()) >= {("public", "d", "e", "integer", False, None)}
 
 
 @dbtest
@@ -147,9 +145,7 @@ def test_foreign_key_query(executor):
         "create table schema2.child(childid int PRIMARY KEY, motherid int REFERENCES schema1.parent)",
     )
 
-    assert set(executor.foreignkeys()) >= {
-        ("schema1", "parent", "parentid", "schema2", "child", "motherid")
-    }
+    assert set(executor.foreignkeys()) >= {("schema1", "parent", "parentid", "schema2", "child", "motherid")}
 
 
 @dbtest
@@ -198,9 +194,7 @@ def test_functions_query(executor):
             return_type="integer",
             is_set_returning=True,
         ),
-        function_meta_data(
-            schema_name="schema1", func_name="func2", return_type="integer"
-        ),
+        function_meta_data(schema_name="schema1", func_name="func2", return_type="integer"),
     }
 
 
@@ -251,9 +245,7 @@ Routine: scanner_yyerror
 
 @dbtest
 def test_invalid_column_name(executor, exception_formatter):
-    result = run(
-        executor, "select invalid command", exception_formatter=exception_formatter
-    )
+    result = run(executor, "select invalid command", exception_formatter=exception_formatter)
     assert 'column "invalid" does not exist' in result[0]
 
 
@@ -268,9 +260,7 @@ def test_unicode_support_in_output(executor, expanded):
     run(executor, "insert into unicodechars (t) values ('é')")
 
     # See issue #24, this raises an exception without proper handling
-    assert "é" in run(
-        executor, "select * from unicodechars", join=True, expanded=expanded
-    )
+    assert "é" in run(executor, "select * from unicodechars", join=True, expanded=expanded)
 
 
 @dbtest
@@ -279,8 +269,8 @@ def test_not_is_special(executor, pgspecial):
     query = "select 1"
     result = list(executor.run(query, pgspecial=pgspecial))
     success, is_special = result[0][5:]
-    assert success == True
-    assert is_special == False
+    assert success is True
+    assert is_special is False
 
 
 @dbtest
@@ -289,8 +279,8 @@ def test_execute_from_file_no_arg(executor, pgspecial):
     result = list(executor.run(r"\i", pgspecial=pgspecial))
     status, sql, success, is_special = result[0][3:]
     assert "missing required argument" in status
-    assert success == False
-    assert is_special == True
+    assert success is False
+    assert is_special is True
 
 
 @dbtest
@@ -304,14 +294,12 @@ def test_execute_from_file_io_error(os, executor, pgspecial):
     result = list(executor.run(r"\i test", pgspecial=pgspecial))
     status, sql, success, is_special = result[0][3:]
     assert status == "test"
-    assert success == False
-    assert is_special == True
+    assert success is False
+    assert is_special is True
 
 
 @dbtest
-def test_execute_from_commented_file_that_executes_another_file(
-    executor, pgspecial, tmpdir
-):
+def test_execute_from_commented_file_that_executes_another_file(executor, pgspecial, tmpdir):
     # https://github.com/dbcli/pgcli/issues/1336
     sqlfile1 = tmpdir.join("test01.sql")
     sqlfile1.write("-- asdf \n\\h")
@@ -321,10 +309,10 @@ def test_execute_from_commented_file_that_executes_another_file(
     rcfile = str(tmpdir.join("rcfile"))
     print(rcfile)
     cli = PGCli(pgexecute=executor, pgclirc_file=rcfile)
-    assert cli != None
+    assert cli is not None
     statement = "--comment\n\\h"
     result = run(executor, statement, pgspecial=cli.pgspecial)
-    assert result != None
+    assert result is not None
     assert result[0].find("ALTER TABLE")
 
 
@@ -333,38 +321,38 @@ def test_execute_commented_first_line_and_special(executor, pgspecial, tmpdir):
     # just some base cases that should work also
     statement = "--comment\nselect now();"
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[1].find("now") >= 0
 
     statement = "/*comment*/\nselect now();"
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[1].find("now") >= 0
 
     # https://github.com/dbcli/pgcli/issues/1362
     statement = "--comment\n\\h"
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[1].find("ALTER") >= 0
     assert result[1].find("ABORT") >= 0
 
     statement = "--comment1\n--comment2\n\\h"
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[1].find("ALTER") >= 0
     assert result[1].find("ABORT") >= 0
 
-    statement = "/*comment*/\n\h;"
+    statement = "/*comment*/\n\\h;"
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[1].find("ALTER") >= 0
     assert result[1].find("ABORT") >= 0
 
-    statement = """/*comment1
+    statement = r"""/*comment1
     comment2*/
     \h"""
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[1].find("ALTER") >= 0
     assert result[1].find("ABORT") >= 0
 
@@ -374,43 +362,43 @@ def test_execute_commented_first_line_and_special(executor, pgspecial, tmpdir):
     comment4*/
     \\h"""
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[1].find("ALTER") >= 0
     assert result[1].find("ABORT") >= 0
 
-    statement = "    /*comment*/\n\h;"
+    statement = "    /*comment*/\n\\h;"
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[1].find("ALTER") >= 0
     assert result[1].find("ABORT") >= 0
 
-    statement = "/*comment\ncomment line2*/\n\h;"
+    statement = "/*comment\ncomment line2*/\n\\h;"
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[1].find("ALTER") >= 0
     assert result[1].find("ABORT") >= 0
 
-    statement = "          /*comment\ncomment line2*/\n\h;"
+    statement = "          /*comment\ncomment line2*/\n\\h;"
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[1].find("ALTER") >= 0
     assert result[1].find("ABORT") >= 0
 
     statement = """\\h /*comment4 */"""
     result = run(executor, statement, pgspecial=pgspecial)
     print(result)
-    assert result != None
+    assert result is not None
     assert result[0].find("No help") >= 0
 
     # TODO: we probably don't want to do this but sqlparse is not parsing things well
     # we relly want it to find help but right now, sqlparse isn't dropping the /*comment*/
     # style comments after command
 
-    statement = """/*comment1*/
+    statement = r"""/*comment1*/
     \h
     /*comment4 */"""
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[0].find("No help") >= 0
 
     # TODO: same for this one
@@ -422,7 +410,7 @@ def test_execute_commented_first_line_and_special(executor, pgspecial, tmpdir):
     comment5
     comment6*/"""
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[0].find("No help") >= 0
 
 
@@ -433,12 +421,12 @@ def test_execute_commented_first_line_and_normal(executor, pgspecial, tmpdir):
     # just some base cases that should work also
     statement = "--comment\nselect now();"
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[1].find("now") >= 0
 
     statement = "/*comment*/\nselect now();"
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[1].find("now") >= 0
 
     # this simulates the original error (1403) without having to add/drop tables
@@ -448,26 +436,26 @@ def test_execute_commented_first_line_and_normal(executor, pgspecial, tmpdir):
     # test that the statement works
     statement = """VALUES (1, 'one'), (2, 'two'), (3, 'three');"""
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[5].find("three") >= 0
 
     # test the statement with a \n in the middle
     statement = """VALUES (1, 'one'),\n (2, 'two'), (3, 'three');"""
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[5].find("three") >= 0
 
     # test the statement with a newline in the middle
     statement = """VALUES (1, 'one'),
      (2, 'two'), (3, 'three');"""
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[5].find("three") >= 0
 
     # now add a single comment line
     statement = """--comment\nVALUES (1, 'one'), (2, 'two'), (3, 'three');"""
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[5].find("three") >= 0
 
     # doing without special char \n
@@ -475,13 +463,13 @@ def test_execute_commented_first_line_and_normal(executor, pgspecial, tmpdir):
     VALUES (1,'one'),
     (2, 'two'), (3, 'three');"""
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[5].find("three") >= 0
 
     # two comment lines
     statement = """--comment\n--comment2\nVALUES (1,'one'), (2, 'two'), (3, 'three');"""
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[5].find("three") >= 0
 
     # doing without special char \n
@@ -490,7 +478,7 @@ def test_execute_commented_first_line_and_normal(executor, pgspecial, tmpdir):
     VALUES (1,'one'), (2, 'two'), (3, 'three');
     """
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[5].find("three") >= 0
 
     # multiline comment + newline in middle of the statement
@@ -500,7 +488,7 @@ comment3*/
 VALUES (1,'one'),
 (2, 'two'), (3, 'three');"""
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[5].find("three") >= 0
 
     # multiline comment + newline in middle of the statement
@@ -513,7 +501,7 @@ VALUES (1,'one'),
 --comment4
 --comment5"""
     result = run(executor, statement, pgspecial=pgspecial)
-    assert result != None
+    assert result is not None
     assert result[5].find("three") >= 0
 
 
@@ -582,9 +570,7 @@ def test_unicode_support_in_enum_type(executor):
 def test_json_renders_without_u_prefix(executor, expanded):
     run(executor, "create table jsontest(d json)")
     run(executor, """insert into jsontest (d) values ('{"name": "Éowyn"}')""")
-    result = run(
-        executor, "SELECT d FROM jsontest LIMIT 1", join=True, expanded=expanded
-    )
+    result = run(executor, "SELECT d FROM jsontest LIMIT 1", join=True, expanded=expanded)
 
     assert '{"name": "Éowyn"}' in result
 
@@ -593,9 +579,7 @@ def test_json_renders_without_u_prefix(executor, expanded):
 def test_jsonb_renders_without_u_prefix(executor, expanded):
     run(executor, "create table jsonbtest(d jsonb)")
     run(executor, """insert into jsonbtest (d) values ('{"name": "Éowyn"}')""")
-    result = run(
-        executor, "SELECT d FROM jsonbtest LIMIT 1", join=True, expanded=expanded
-    )
+    result = run(executor, "SELECT d FROM jsonbtest LIMIT 1", join=True, expanded=expanded)
 
     assert '{"name": "Éowyn"}' in result
 
@@ -603,28 +587,10 @@ def test_jsonb_renders_without_u_prefix(executor, expanded):
 @dbtest
 def test_date_time_types(executor):
     run(executor, "SET TIME ZONE UTC")
-    assert (
-        run(executor, "SELECT (CAST('00:00:00' AS time))", join=True).split("\n")[3]
-        == "| 00:00:00 |"
-    )
-    assert (
-        run(executor, "SELECT (CAST('00:00:00+14:59' AS timetz))", join=True).split(
-            "\n"
-        )[3]
-        == "| 00:00:00+14:59 |"
-    )
-    assert (
-        run(executor, "SELECT (CAST('4713-01-01 BC' AS date))", join=True).split("\n")[
-            3
-        ]
-        == "| 4713-01-01 BC |"
-    )
-    assert (
-        run(
-            executor, "SELECT (CAST('4713-01-01 00:00:00 BC' AS timestamp))", join=True
-        ).split("\n")[3]
-        == "| 4713-01-01 00:00:00 BC |"
-    )
+    assert run(executor, "SELECT (CAST('00:00:00' AS time))", join=True).split("\n")[3] == "| 00:00:00 |"
+    assert run(executor, "SELECT (CAST('00:00:00+14:59' AS timetz))", join=True).split("\n")[3] == "| 00:00:00+14:59 |"
+    assert run(executor, "SELECT (CAST('4713-01-01 BC' AS date))", join=True).split("\n")[3] == "| 4713-01-01 BC |"
+    assert run(executor, "SELECT (CAST('4713-01-01 00:00:00 BC' AS timestamp))", join=True).split("\n")[3] == "| 4713-01-01 00:00:00 BC |"
     assert (
         run(
             executor,
@@ -634,10 +600,7 @@ def test_date_time_types(executor):
         == "| 4713-01-01 00:00:00+00 BC |"
     )
     assert (
-        run(
-            executor, "SELECT (CAST('-123456789 days 12:23:56' AS interval))", join=True
-        ).split("\n")[3]
-        == "| -123456789 days, 12:23:56 |"
+        run(executor, "SELECT (CAST('-123456789 days 12:23:56' AS interval))", join=True).split("\n")[3] == "| -123456789 days, 12:23:56 |"
     )
 
 
@@ -670,20 +633,14 @@ def test_raises_with_no_formatter(executor, sql):
 @dbtest
 def test_on_error_resume(executor, exception_formatter):
     sql = "select 1; error; select 1;"
-    result = list(
-        executor.run(sql, on_error_resume=True, exception_formatter=exception_formatter)
-    )
+    result = list(executor.run(sql, on_error_resume=True, exception_formatter=exception_formatter))
     assert len(result) == 3
 
 
 @dbtest
 def test_on_error_stop(executor, exception_formatter):
     sql = "select 1; error; select 1;"
-    result = list(
-        executor.run(
-            sql, on_error_resume=False, exception_formatter=exception_formatter
-        )
-    )
+    result = list(executor.run(sql, on_error_resume=False, exception_formatter=exception_formatter))
     assert len(result) == 2
 
 
@@ -697,7 +654,7 @@ def test_on_error_stop(executor, exception_formatter):
 @dbtest
 def test_nonexistent_function_definition(executor):
     with pytest.raises(RuntimeError):
-        result = executor.view_definition("there_is_no_such_function")
+        executor.view_definition("there_is_no_such_function")
 
 
 @dbtest
@@ -713,7 +670,7 @@ def test_function_definition(executor):
             $function$
     """,
     )
-    result = executor.function_definition("the_number_three")
+    executor.function_definition("the_number_three")
 
 
 @dbtest
@@ -764,9 +721,9 @@ def test_view_definition(executor):
 @dbtest
 def test_nonexistent_view_definition(executor):
     with pytest.raises(RuntimeError):
-        result = executor.view_definition("there_is_no_such_view")
+        executor.view_definition("there_is_no_such_view")
     with pytest.raises(RuntimeError):
-        result = executor.view_definition("mvw1")
+        executor.view_definition("mvw1")
 
 
 @dbtest
@@ -775,9 +732,7 @@ def test_short_host(executor):
         assert executor.short_host == "localhost"
     with patch.object(executor, "host", "localhost.example.org"):
         assert executor.short_host == "localhost"
-    with patch.object(
-        executor, "host", "localhost1.example.org,localhost2.example.org"
-    ):
+    with patch.object(executor, "host", "localhost1.example.org,localhost2.example.org"):
         assert executor.short_host == "localhost1"
     with patch.object(executor, "host", "ec2-11-222-333-444.compute-1.amazonaws.com"):
         assert executor.short_host == "ec2-11-222-333-444"
@@ -814,9 +769,7 @@ def test_exit_without_active_connection(executor):
         aliases=(":q",),
     )
 
-    with patch.object(
-        executor.conn, "cursor", side_effect=psycopg.InterfaceError("I'm broken!")
-    ):
+    with patch.object(executor.conn, "cursor", side_effect=psycopg.InterfaceError("I'm broken!")):
         # we should be able to quit the app, even without active connection
         run(executor, "\\q", pgspecial=pgspecial)
         quit_handler.assert_called_once()
