@@ -11,7 +11,6 @@ from metadata import (
     wildcard_expansion,
     column,
     get_result,
-    result_set,
     qual,
     no_qual,
     parametrize,
@@ -125,9 +124,7 @@ completers = testdata.get_completers(casing)
 @parametrize("table", ["users", '"users"'])
 def test_suggested_column_names_from_shadowed_visible_table(completer, table):
     result = get_result(completer, "SELECT  FROM " + table, len("SELECT "))
-    assert completions_to_set(result) == completions_to_set(
-        testdata.columns_functions_and_keywords("users")
-    )
+    assert completions_to_set(result) == completions_to_set(testdata.columns_functions_and_keywords("users"))
 
 
 @parametrize("completer", completers(filtr=True, casing=False, qualify=no_qual))
@@ -140,18 +137,14 @@ def test_suggested_column_names_from_shadowed_visible_table(completer, table):
 )
 def test_suggested_column_names_from_qualified_shadowed_table(completer, text):
     result = get_result(completer, text, position=text.find("  ") + 1)
-    assert completions_to_set(result) == completions_to_set(
-        testdata.columns_functions_and_keywords("users", "custom")
-    )
+    assert completions_to_set(result) == completions_to_set(testdata.columns_functions_and_keywords("users", "custom"))
 
 
 @parametrize("completer", completers(filtr=True, casing=False, qualify=no_qual))
 @parametrize("text", ["WITH users as (SELECT 1 AS foo) SELECT  from users"])
 def test_suggested_column_names_from_cte(completer, text):
     result = completions_to_set(get_result(completer, text, text.find("  ") + 1))
-    assert result == completions_to_set(
-        [column("foo")] + testdata.functions_and_keywords()
-    )
+    assert result == completions_to_set([column("foo")] + testdata.functions_and_keywords())
 
 
 @parametrize("completer", completers(casing=False))
@@ -166,14 +159,12 @@ def test_suggested_column_names_from_cte(completer, text):
 )
 def test_suggested_join_conditions(completer, text):
     result = get_result(completer, text)
-    assert completions_to_set(result) == completions_to_set(
-        [
-            alias("users"),
-            alias("shipments"),
-            name_join("shipments.id = users.id"),
-            fk_join("shipments.user_id = users.id"),
-        ]
-    )
+    assert completions_to_set(result) == completions_to_set([
+        alias("users"),
+        alias("shipments"),
+        name_join("shipments.id = users.id"),
+        fk_join("shipments.user_id = users.id"),
+    ])
 
 
 @parametrize("completer", completers(filtr=True, casing=False, aliasing=False))
@@ -192,17 +183,14 @@ def test_suggested_join_conditions(completer, text):
 def test_suggested_joins(completer, query, tbl):
     result = get_result(completer, query.format(tbl))
     assert completions_to_set(result) == completions_to_set(
-        testdata.schemas_and_from_clause_items()
-        + [join(f"custom.shipments ON shipments.user_id = {tbl}.id")]
+        testdata.schemas_and_from_clause_items() + [join(f"custom.shipments ON shipments.user_id = {tbl}.id")]
     )
 
 
 @parametrize("completer", completers(filtr=True, casing=False, qualify=no_qual))
 def test_suggested_column_names_from_schema_qualifed_table(completer):
     result = get_result(completer, "SELECT  from custom.products", len("SELECT "))
-    assert completions_to_set(result) == completions_to_set(
-        testdata.columns_functions_and_keywords("products", "custom")
-    )
+    assert completions_to_set(result) == completions_to_set(testdata.columns_functions_and_keywords("products", "custom"))
 
 
 @parametrize(
@@ -216,19 +204,13 @@ def test_suggested_column_names_from_schema_qualifed_table(completer):
 )
 @parametrize("completer", completers(filtr=True, casing=False))
 def test_suggested_columns_with_insert(completer, text):
-    assert completions_to_set(get_result(completer, text)) == completions_to_set(
-        testdata.columns("orders")
-    )
+    assert completions_to_set(get_result(completer, text)) == completions_to_set(testdata.columns("orders"))
 
 
 @parametrize("completer", completers(filtr=True, casing=False, qualify=no_qual))
 def test_suggested_column_names_in_function(completer):
-    result = get_result(
-        completer, "SELECT MAX( from custom.products", len("SELECT MAX(")
-    )
-    assert completions_to_set(result) == completions_to_set(
-        testdata.columns_functions_and_keywords("products", "custom")
-    )
+    result = get_result(completer, "SELECT MAX( from custom.products", len("SELECT MAX("))
+    assert completions_to_set(result) == completions_to_set(testdata.columns_functions_and_keywords("products", "custom"))
 
 
 @parametrize("completer", completers(casing=False, aliasing=False))
@@ -237,9 +219,7 @@ def test_suggested_column_names_in_function(completer):
     ["SELECT * FROM Custom.", "SELECT * FROM custom.", 'SELECT * FROM "custom".'],
 )
 @parametrize("use_leading_double_quote", [False, True])
-def test_suggested_table_names_with_schema_dot(
-    completer, text, use_leading_double_quote
-):
+def test_suggested_table_names_with_schema_dot(completer, text, use_leading_double_quote):
     if use_leading_double_quote:
         text += '"'
         start_position = -1
@@ -247,17 +227,13 @@ def test_suggested_table_names_with_schema_dot(
         start_position = 0
 
     result = get_result(completer, text)
-    assert completions_to_set(result) == completions_to_set(
-        testdata.from_clause_items("custom", start_position)
-    )
+    assert completions_to_set(result) == completions_to_set(testdata.from_clause_items("custom", start_position))
 
 
 @parametrize("completer", completers(casing=False, aliasing=False))
 @parametrize("text", ['SELECT * FROM "Custom".'])
 @parametrize("use_leading_double_quote", [False, True])
-def test_suggested_table_names_with_schema_dot2(
-    completer, text, use_leading_double_quote
-):
+def test_suggested_table_names_with_schema_dot2(completer, text, use_leading_double_quote):
     if use_leading_double_quote:
         text += '"'
         start_position = -1
@@ -265,37 +241,25 @@ def test_suggested_table_names_with_schema_dot2(
         start_position = 0
 
     result = get_result(completer, text)
-    assert completions_to_set(result) == completions_to_set(
-        testdata.from_clause_items("Custom", start_position)
-    )
+    assert completions_to_set(result) == completions_to_set(testdata.from_clause_items("Custom", start_position))
 
 
 @parametrize("completer", completers(filtr=True, casing=False))
 def test_suggested_column_names_with_qualified_alias(completer):
     result = get_result(completer, "SELECT p. from custom.products p", len("SELECT p."))
-    assert completions_to_set(result) == completions_to_set(
-        testdata.columns("products", "custom")
-    )
+    assert completions_to_set(result) == completions_to_set(testdata.columns("products", "custom"))
 
 
 @parametrize("completer", completers(filtr=True, casing=False, qualify=no_qual))
 def test_suggested_multiple_column_names(completer):
-    result = get_result(
-        completer, "SELECT id,  from custom.products", len("SELECT id, ")
-    )
-    assert completions_to_set(result) == completions_to_set(
-        testdata.columns_functions_and_keywords("products", "custom")
-    )
+    result = get_result(completer, "SELECT id,  from custom.products", len("SELECT id, "))
+    assert completions_to_set(result) == completions_to_set(testdata.columns_functions_and_keywords("products", "custom"))
 
 
 @parametrize("completer", completers(filtr=True, casing=False))
 def test_suggested_multiple_column_names_with_alias(completer):
-    result = get_result(
-        completer, "SELECT p.id, p. from custom.products p", len("SELECT u.id, u.")
-    )
-    assert completions_to_set(result) == completions_to_set(
-        testdata.columns("products", "custom")
-    )
+    result = get_result(completer, "SELECT p.id, p. from custom.products p", len("SELECT u.id, u."))
+    assert completions_to_set(result) == completions_to_set(testdata.columns("products", "custom"))
 
 
 @parametrize("completer", completers(filtr=True, casing=False))
@@ -307,19 +271,15 @@ def test_suggested_multiple_column_names_with_alias(completer):
     ],
 )
 def test_suggestions_after_on(completer, text):
-    position = len(
-        "SELECT x.id, y.product_name FROM custom.products x JOIN custom.products y ON "
-    )
+    position = len("SELECT x.id, y.product_name FROM custom.products x JOIN custom.products y ON ")
     result = get_result(completer, text, position)
-    assert completions_to_set(result) == completions_to_set(
-        [
-            alias("x"),
-            alias("y"),
-            name_join("y.price = x.price"),
-            name_join("y.product_name = x.product_name"),
-            name_join("y.id = x.id"),
-        ]
-    )
+    assert completions_to_set(result) == completions_to_set([
+        alias("x"),
+        alias("y"),
+        name_join("y.price = x.price"),
+        name_join("y.product_name = x.product_name"),
+        name_join("y.id = x.id"),
+    ])
 
 
 @parametrize("completer", completers())
@@ -333,32 +293,26 @@ def test_suggested_aliases_after_on_right_side(completer):
 def test_table_names_after_from(completer):
     text = "SELECT * FROM "
     result = get_result(completer, text)
-    assert completions_to_set(result) == completions_to_set(
-        testdata.schemas_and_from_clause_items()
-    )
+    assert completions_to_set(result) == completions_to_set(testdata.schemas_and_from_clause_items())
 
 
 @parametrize("completer", completers(filtr=True, casing=False))
 def test_schema_qualified_function_name(completer):
     text = "SELECT custom.func"
     result = get_result(completer, text)
-    assert completions_to_set(result) == completions_to_set(
-        [
-            function("func3()", -len("func")),
-            function("set_returning_func()", -len("func")),
-        ]
-    )
+    assert completions_to_set(result) == completions_to_set([
+        function("func3()", -len("func")),
+        function("set_returning_func()", -len("func")),
+    ])
 
 
 @parametrize("completer", completers(filtr=True, casing=False, aliasing=False))
 def test_schema_qualified_function_name_after_from(completer):
     text = "SELECT * FROM custom.set_r"
     result = get_result(completer, text)
-    assert completions_to_set(result) == completions_to_set(
-        [
-            function("set_returning_func()", -len("func")),
-        ]
-    )
+    assert completions_to_set(result) == completions_to_set([
+        function("set_returning_func()", -len("func")),
+    ])
 
 
 @parametrize("completer", completers(filtr=True, casing=False, aliasing=False))
@@ -373,11 +327,9 @@ def test_unqualified_function_name_in_search_path(completer):
     completer.search_path = ["public", "custom"]
     text = "SELECT * FROM set_r"
     result = get_result(completer, text)
-    assert completions_to_set(result) == completions_to_set(
-        [
-            function("set_returning_func()", -len("func")),
-        ]
-    )
+    assert completions_to_set(result) == completions_to_set([
+        function("set_returning_func()", -len("func")),
+    ])
 
 
 @parametrize("completer", completers(filtr=True, casing=False))
@@ -397,12 +349,8 @@ def test_schema_qualified_type_name(completer, text):
 
 @parametrize("completer", completers(filtr=True, casing=False))
 def test_suggest_columns_from_aliased_set_returning_function(completer):
-    result = get_result(
-        completer, "select f. from custom.set_returning_func() f", len("select f.")
-    )
-    assert completions_to_set(result) == completions_to_set(
-        testdata.columns("set_returning_func", "custom", "functions")
-    )
+    result = get_result(completer, "select f. from custom.set_returning_func() f", len("select f."))
+    assert completions_to_set(result) == completions_to_set(testdata.columns("set_returning_func", "custom", "functions"))
 
 
 @parametrize("completer", completers(filtr=True, casing=False, qualify=no_qual))
@@ -499,10 +447,7 @@ def test_wildcard_column_expansion_with_two_tables(completer):
 
     completions = get_result(completer, text, position)
 
-    cols = (
-        '"select".id, "select"."localtime", "select"."ABC", '
-        "users.id, users.phone_number"
-    )
+    cols = '"select".id, "select"."localtime", "select"."ABC", users.id, users.phone_number'
     expected = [wildcard_expansion(cols)]
     assert completions == expected
 
@@ -535,21 +480,15 @@ def test_wildcard_column_expansion_with_two_tables_and_parent(completer):
 def test_suggest_columns_from_unquoted_table(completer, text):
     position = len("SELECT U.")
     result = get_result(completer, text, position)
-    assert completions_to_set(result) == completions_to_set(
-        testdata.columns("users", "custom")
-    )
+    assert completions_to_set(result) == completions_to_set(testdata.columns("users", "custom"))
 
 
 @parametrize("completer", completers(filtr=True, casing=False))
-@parametrize(
-    "text", ['SELECT U. FROM custom."Users" U', 'SELECT U. FROM "custom"."Users" U']
-)
+@parametrize("text", ['SELECT U. FROM custom."Users" U', 'SELECT U. FROM "custom"."Users" U'])
 def test_suggest_columns_from_quoted_table(completer, text):
     position = len("SELECT U.")
     result = get_result(completer, text, position)
-    assert completions_to_set(result) == completions_to_set(
-        testdata.columns("Users", "custom")
-    )
+    assert completions_to_set(result) == completions_to_set(testdata.columns("Users", "custom"))
 
 
 texts = ["SELECT * FROM ", "SELECT * FROM public.Orders O CROSS JOIN "]
@@ -559,9 +498,7 @@ texts = ["SELECT * FROM ", "SELECT * FROM public.Orders O CROSS JOIN "]
 @parametrize("text", texts)
 def test_schema_or_visible_table_completion(completer, text):
     result = get_result(completer, text)
-    assert completions_to_set(result) == completions_to_set(
-        testdata.schemas_and_from_clause_items()
-    )
+    assert completions_to_set(result) == completions_to_set(testdata.schemas_and_from_clause_items())
 
 
 @parametrize("completer", completers(aliasing=True, casing=False, filtr=True))
@@ -703,9 +640,7 @@ def test_column_alias_search(completer):
 
 @parametrize("completer", completers(casing=True))
 def test_column_alias_search_qualified(completer):
-    result = get_result(
-        completer, "SELECT E.ei FROM blog.Entries E", len("SELECT E.ei")
-    )
+    result = get_result(completer, "SELECT E.ei FROM blog.Entries E", len("SELECT E.ei"))
     cols = ("EntryID", "EntryTitle")
     assert result[:3] == [column(c, -2) for c in cols]
 
@@ -713,9 +648,7 @@ def test_column_alias_search_qualified(completer):
 @parametrize("completer", completers(casing=False, filtr=False, aliasing=False))
 def test_schema_object_order(completer):
     result = get_result(completer, "SELECT * FROM u")
-    assert result[:3] == [
-        table(t, pos=-1) for t in ("users", 'custom."Users"', "custom.users")
-    ]
+    assert result[:3] == [table(t, pos=-1) for t in ("users", 'custom."Users"', "custom.users")]
 
 
 @parametrize("completer", completers(casing=False, filtr=False, aliasing=False))
@@ -723,8 +656,7 @@ def test_all_schema_objects(completer):
     text = "SELECT * FROM "
     result = get_result(completer, text)
     assert completions_to_set(result) >= completions_to_set(
-        [table(x) for x in ("orders", '"select"', "custom.shipments")]
-        + [function(x + "()") for x in ("func2",)]
+        [table(x) for x in ("orders", '"select"', "custom.shipments")] + [function(x + "()") for x in ("func2",)]
     )
 
 
@@ -733,8 +665,7 @@ def test_all_schema_objects_with_casing(completer):
     text = "SELECT * FROM "
     result = get_result(completer, text)
     assert completions_to_set(result) >= completions_to_set(
-        [table(x) for x in ("Orders", '"select"', "CUSTOM.shipments")]
-        + [function(x + "()") for x in ("func2",)]
+        [table(x) for x in ("Orders", '"select"', "CUSTOM.shipments")] + [function(x + "()") for x in ("func2",)]
     )
 
 
@@ -743,8 +674,7 @@ def test_all_schema_objects_with_aliases(completer):
     text = "SELECT * FROM "
     result = get_result(completer, text)
     assert completions_to_set(result) >= completions_to_set(
-        [table(x) for x in ("orders o", '"select" s', "custom.shipments s")]
-        + [function(x) for x in ("func2() f",)]
+        [table(x) for x in ("orders o", '"select" s', "custom.shipments s")] + [function(x) for x in ("func2() f",)]
     )
 
 
@@ -752,6 +682,4 @@ def test_all_schema_objects_with_aliases(completer):
 def test_set_schema(completer):
     text = "SET SCHEMA "
     result = get_result(completer, text)
-    assert completions_to_set(result) == completions_to_set(
-        [schema("'blog'"), schema("'Custom'"), schema("'custom'"), schema("'public'")]
-    )
+    assert completions_to_set(result) == completions_to_set([schema("'blog'"), schema("'Custom'"), schema("'custom'"), schema("'public'")])
